@@ -66,8 +66,8 @@ class BlobFS(GenericFS):
     def ls(self, path=""):
         path_ = self.path(path)
         name_starts_with = path_ if path_ == '' else path_ + '/'
-        self.log.debug("Blobcontents.BlobFS.ls: Listing directory: `%s`", path_)
-        blob_list = self.container_client.list_blobs(name_starts_with=path_)
+        self.log.debug("Blobcontents.BlobFS.ls: Listing directory: `%s`", name_starts_with)
+        blob_list = self.container_client.list_blobs(name_starts_with=name_starts_with)
         files = list(map(lambda blob: blob.name, blob_list))
         self.log.debug("Blobcontents.BlobFS.ls: files: `%s`", files)
         files = list(map(lambda name: self.blob_mapper(name, path_), files))
